@@ -8,21 +8,22 @@ This program is free software and comes with ABSOLUTELY NO WARRANTY; for details
 from unittest.mock import Mock
 from unittest import TestCase
 
-from LabExT.Movement.Stage import StageError, assert_stage_connected
+from LabExT.Movement.Stage import Stage, StageError, assert_stage_connected, assert_driver_loaded
+from LabExT.Movement.Stages.DummyStage import DummyStage
 
 
 class StageTest(TestCase):
     def setUp(self) -> None:
         self.stage = Mock()
 
-    def test_assert_stage_connected_raises_error_if_driver_not_loaded(self):
+    def test_assert_driver_loaded_raises_error_if_driver_not_loaded(self):
         self.stage.driver_loaded = False
 
         func = Mock()
         func.__name__ = 'Dummy Function'
 
         with self.assertRaises(StageError):
-            assert_stage_connected(func)(self.stage)
+            assert_driver_loaded(func)(self.stage)
 
         func.assert_not_called()
 
@@ -37,14 +38,3 @@ class StageTest(TestCase):
             assert_stage_connected(func)(self.stage)
 
         func.assert_not_called()
-
-    def test_assert_stage_connected_raises_error(self):
-        self.stage.driver_loaded = True
-        self.stage.connected = True
-
-        func = Mock()
-        func.__name__ = 'Dummy Function'
-
-        assert_stage_connected(func)(self.stage)
-
-        func.assert_called_once()
